@@ -31,6 +31,7 @@ from rbbz.errors import (BugzillaError,
                          ConfidentialBugError,
                          InvalidBugIdError)
 from rbbz.middleware import BugzillaCookieAuthMiddleware
+from rbbz.resources import bugzilla_cookie_login_resource
 
 
 REVIEWID_RE = re.compile('bz://(\d+)/[^/]+')
@@ -63,6 +64,10 @@ DRAFTED_EXTRA_DATA_KEYS = [
 class BugzillaExtension(Extension):
     middleware = [BugzillaCookieAuthMiddleware]
 
+    resources = [
+        bugzilla_cookie_login_resource,
+    ]
+
     def initialize(self):
         AuthBackendHook(self, BugzillaBackend)
         SignalHook(self, pre_delete, on_draft_pre_delete)
@@ -328,7 +333,9 @@ def on_reply_publishing(user, reply, **kwargs):
     bug_id = int(review_request.get_bug_list()[0])
     b = Bugzilla(user.bzlogin, user.bzcookie)
 
-    b.post_comment(bug_id, build_plaintext_review(reply, {"user": user}))
+    url = review_or_request_url(reply)
+    comment = build_plaintext_review(reply, url, {"user": user})
+    b.post_comment(bug_id, comment)
 
 
 def on_review_request_closed_discarded(user, review_request, type, **kwargs):
